@@ -3,8 +3,7 @@
 import logging
 from datetime import timedelta
 
-from celery.schedules import crontab
-from celery.task import periodic_task
+from celery import shared_task
 from django.utils import timezone
 
 from core_user_registration_app.settings import (
@@ -15,14 +14,15 @@ from core_user_registration_app.system import api as system_api
 logger = logging.getLogger(__name__)
 
 
-@periodic_task(run_every=crontab(minute="*"))
+@shared_task
 def delete_user_data_structure():
     """DELETES every DELETE_USER_DATA_STRUCTURE_RATE the UserDataStructure in the DataStructure collection"""
     logger.info("Checking Old UserDataStructures")
     try:
         for data_structure_element in system_api.get_all_data_structure_elements():
             if (
-                data_structure_element.data_structure.collection
+                data_structure_element.data_structure
+                and data_structure_element.data_structure.collection
                 == "user_data_structure"
             ):
                 if (
